<?php

namespace App\Controllers;

use App\Core\Database;
use App\Services\AuthService;
use App\Services\LanguageService;
use App\Utils\DarkMode;

/**
 * Contrôleur pour la page du tableau de bord.
 */
class DashboardController
{
    private $authService;
    private $langService;

    /**
     * Constructeur du DashboardController.
     */
    public function __construct()
    {
        $this->authService = new AuthService(Database::getInstance());
        $this->langService = new LanguageService(APP_ROOT_DIR . '/src/Lang/');
    }

    /**
     * Affiche le tableau de bord.
     * Redirige vers la page de connexion si l'utilisateur n'est pas connecté.
     */
    public function index()
    {
        if (!$this->authService->isLoggedIn()) {
            header('Location: /login');
            exit();
        }

        // Récupère les traductions et les informations pour la vue
        global $translations;
        $currentLang = $this->langService->getLanguage();
        $username = $this->authService->getUsername();
        $darkModeClass = DarkMode::getBodyClass();
        $userRole = $this->authService->getUserRole(); // Pour afficher/masquer certains éléments

        require_once APP_ROOT_DIR . '/src/Views/dashboard/index.php';
    }
}
